.. Yuhi documentation master file, created by
   sphinx-quickstart on Fri Feb 21 03:34:10 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Yuhi documentation
==================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.


.. toctree::
   :maxdepth: 2
   :caption: Contents:
